"""
Droplet Deformation (DropDeform)

Determine droplet deformation into Polyhedron Shape.

Source code of DropDeform: https://git.rwth-aachen.de/avt-fvt/public/droplet-deformation/

The source code of DropDeform is licensed under the Eclipse Public License v2.0 (EPL 2.0).
Copyright (c) 2025 Fluid Process Engineering (AVT.FVT), RWTH Aachen University.
Written by Stepan Sibirtsev

The coyprights and license terms are given in LICENSE.

In this script configurations for the DropDeform_main.py script are set.
Script version date: 06.01.2025
""" 

# Number of steps in pressure and droplet diameter
n_steps = 10
# Minimum pressure [Pa]
p_min = 0.2
# Maximum pressure [Pa]
p_max = 200
# Minimum droplet diameter [µm]
d_min = 150
# Maximum droplet diameter [µm]
d_max = 1500
# Minimum interfacial tension [mN/m]
sigma_min = 2
# Maximum interfacial tension [mN/m]
sigma_max = 50
# Output Excel file with the simulation data of the droplet deformation.
# Default: Test
name_output_file = 'Test'
# Fitting method for the Bond number correlation
# 0 = fit each polyhedron shape individualy, 1 = fit general parameters to all polyhedron shapes
fit_meth = 1
# Transform Bond numbers of the results to logarithmic scale to achieve a more even distribution of the data?
log_scale = True
# Number of bins to choose an equal number of randomly chosen iterative solution results within these bins 
n_bins = 200
# Display solver warnings? False = no, True = yes
# Useful for developers.
# Default: False
display_solver_warnings = False
# Gravitational constant g[m/s²]
grav = 9.81
# Value next to zeroto avoid numerical iussues during simulation
zero = 1e-9
""" Configuration ends here """
# Assign parameter to int and float
n_steps = int(n_steps)
fit_meth = int(fit_meth)
n_bins = int(n_bins)
p_min = float(p_min)
p_max = float(p_max)
d_min = float(d_min/1e+6)
d_max = float(d_max/1e+6)
sigma_min = float(sigma_min/1e+3)
sigma_max = float(sigma_max/1e+3)
grav = float(grav)
zero = float(zero)