"""
Droplet Deformation (DropDeform)

Determine droplet deformation into Polyhedron Shape.

Source code of DropDeform: https://git.rwth-aachen.de/avt-fvt/public/droplet-deformation/

The source code of DropDeform is licensed under the Eclipse Public License v2.0 (EPL 2.0).
Copyright (c) 2025 Fluid Process Engineering (AVT.FVT), RWTH Aachen University.
Written by Stepan Sibirtsev

The coyprights and license terms are given in LICENSE.

This script contains all functions to export the results to excel.
Script version date: 06.01.2025
""" 

""" Import packages """
import os
import xlwt
import pandas as pd

""" Functions """
def save_excel(ROOT_DIR_OUTPUT, NAME_OUTPUT_FILE, M_deform):
    # Convert the arrays into dataframes
    M_ra_df = pd.DataFrame(M_deform[0,:,:])
    M_rf_df = pd.DataFrame(M_deform[1,:,:])
    M_eps_df = pd.DataFrame(M_deform[2,:,:])
    # Define headers
    headers_ra = ['Bo [-]', '2*ra/d [-]']
    headers_rf = ['Bo [-]', '2*rf/d [-]']
    headers_eps = ['Bo [-]', 'eps [%]']
    # Create a new Excel workbook
    workbook = xlwt.Workbook()
    # Create a new Excel sheet for r_a data
    sheet_ra = workbook.add_sheet('r_a')
    # Write r_a headers to Excel
    for col_index, header in enumerate(headers_ra):
        sheet_ra.write(0, col_index, header)
    # Write r_a data to Excel
    for row_index, values in enumerate(M_ra_df.values):
        for col_index, value in enumerate(values):
            sheet_ra.write(row_index + 1, col_index, value)
    # Create a new Excel sheet for r_a data
    sheet_rf = workbook.add_sheet('r_f')
    # Write r_f headers to Excel
    for col_index, header in enumerate(headers_rf):
        sheet_rf.write(0, col_index, header)
    # Write r_f data to Excel
    for row_index, values in enumerate(M_rf_df.values):
        for col_index, value in enumerate(values):
            sheet_rf.write(row_index + 1, col_index, value)
    # Create a new Excel sheet for hold-up data
    sheet_eps = workbook.add_sheet('eps')
    # Write r_f headers to Excel
    for col_index, header in enumerate(headers_eps):
        sheet_eps.write(0, col_index, header)
    # Write r_f data to Excel
    for row_index, values in enumerate(M_eps_df.values):
        for col_index, value in enumerate(values):
            sheet_eps.write(row_index + 1, col_index, value)
    # Save the workbook to a file
    file_name = os.path.join(ROOT_DIR_OUTPUT, NAME_OUTPUT_FILE)
    workbook.save(file_name)