"""
Droplet Deformation (DropDeform)

Determine droplet deformation into Polyhedron Shape.

Source code of DropDeform: https://git.rwth-aachen.de/avt-fvt/public/droplet-deformation/

The source code of DropDeform is licensed under the Eclipse Public License v2.0 (EPL 2.0).
Copyright (c) 2025 Fluid Process Engineering (AVT.FVT), RWTH Aachen University.
Written by Stepan Sibirtsev

The coyprights and license terms are given in LICENSE.

In this script polyhedral shape parameters for the DropDeform_main.py script are set.
Script version date: 06.01.2025
""" 

""" Import packages """
import numpy as np
""" Define Polyhedral shape parameters """
# Predefine polyhedron shape specific constants for:
# Polyhedron volume
C_V = np.zeros(5)
# Polygon face area
C_A = np.zeros(5)
# Polygon incircle radius
C_rc = np.zeros(5)
# Polyhedron midsphere radius
C_rm = np.zeros(5)
# Polyhedron insphere radius
C_rs = np.zeros(5)
# Number of edges
n_e = np.zeros(5)
# Number of corners
n_c = np.zeros(5)
# Number of polygon faces
n_f = np.zeros(5)
# Iterate through the five polyhedron shapes and assign the polyhedral shape parameters
for ish in range(5):
    # Tetrahedron
    if ish == 0:
        # Polyhedron volume
        C_V[ish] = 1.0 / (6.0 * 2.0**0.5)
        # Polygon face area
        C_A[ish] = (3.0**0.5) / 4.0
        # Polygon incircle radius
        C_rc[ish] = (3.0**0.5) / 6.0
        # Polyhedron midsphere radius
        C_rm[ish] = 1.0 / (8.0**0.5)
        # Polyhedron insphere radius 
        C_rs[ish] = 1.0 / (24.0**0.5)  
        # Number of edges 
        n_e[ish] = 6.0
        # Number of corners
        n_c[ish] = 4.0
        # Number of polygon faces
        n_f[ish] = 4.0
    # Cube       
    elif ish == 1:
        # Polyhedron volume
        C_V[ish] = 1.0 
        # Polygon face area
        C_A[ish] = 1.0
        # Polygon incircle radius
        C_rc[ish] = 0.5
        # Polyhedron midsphere radius
        C_rm[ish] = 1.0 / (2.0**0.5)
        # Polyhedron insphere radius 
        C_rs[ish] = 0.5
        # Number of edges 
        n_e[ish] = 12.0
        # Number of corners
        n_c[ish] = 8.0
        # Number of polygon faces
        n_f[ish] = 6.0
    # Octahedron
    elif ish == 2:
        # Polyhedron volume
        C_V[ish] = (2.0**0.5) / 3.0
        # Polygon face area
        C_A[ish] = (3.0**0.5) / 4.0
        # Polygon incircle radius
        C_rc[ish] = (3.0**0.5) / 6.0
        # Polyhedron midsphere radius
        C_rm[ish] = 0.5
        # Polyhedron insphere radius 
        C_rs[ish] = 1.0 / (6.0**0.5)
        # Number of edges 
        n_e[ish] = 12.0
        # Number of corners
        n_c[ish] = 6.0
        # Number of polygon faces
        n_f[ish] = 8.0
    # Dodecahedron
    elif ish == 3:
        # Polyhedron volume
        C_V[ish] = (15.0 + 7.0*(5.0**0.5)) / 4.0            
        # Polygon face area
        C_A[ish] = ((5.0*(5.0+2.0*(5.0**0.5)))**0.5) / 4.0
        # Polygon incircle radius
        C_rc[ish] = ((1.0+2.0/(5.0**0.5))**0.5) / 2.0
        # Polyhedron midsphere radius
        C_rm[ish] = (3.0+5.0**0.5) / 4.0
        # Polyhedron insphere radius 
        C_rs[ish] = ((10.0*(25.0+11.0*(5.0**0.5)))**0.5) / 20.0
        # Number of edges 
        n_e[ish] = 30.0
        # Number of corners
        n_c[ish] = 20.0
        # Number of polygon faces
        n_f[ish] = 12.0
    # Icosahedron
    elif ish == 4:
        # Polyhedron volume
        C_V[ish] = 5.0 * (3.0 + 5.0**0.5) / 12.0
        # Polygon face area
        C_A[ish] = (3.0**0.5) / 4.0
        # Polygon incircle radius
        C_rc[ish] = (3.0**0.5) / 6.0
        # Polyhedron midsphere radius
        C_rm[ish] = (1.0+5.0**0.5) / 4.0
        # Polyhedron insphere radius 
        C_rs[ish] = ((3.0**0.5)*(3.0+5.0**0.5)) / 12.0
        # Number of edges 
        n_e[ish] = 30.0
        # Number of corners
        n_c[ish] = 12.0
        # Number of polygon faces
        n_f[ish] = 20.0